@@ -20,4 +20,12 @@ pub enum Error {
     NothingToDo,
     #[error("not implemented")]
     NotImplemented,
+    #[error("cannot watch file: {0}")]
+    CannotWatch(String),
+    #[error("test runner not supported: {0}")]
+    TestRunnerNotSupported(String),
+    #[error("reporter error")]
+    ReporterError(#[from] crate::reporter::Error),
+    #[error("report unavailable")]
+    ReportUnavailable,
 }
