@@ -10,16 +10,17 @@ pub mod test;
 pub mod test_runners;
 
 pub use actions::Action;
-pub use actions::Actions;
 pub use actions::Source;
 pub use actions::TestDataIn;
 pub use actions::TestDataOut;
 pub use errors::Error;
 pub use exec::Executable;
 pub use lang::Language;
+pub use report::Failure;
 pub use report::Report;
 pub use report::TestCase;
 pub use report::TestSuite;
+pub use reporter::Error as ReporterError;
 pub use reporter::Reporter;
-pub use reporter::SimpleReporter;
+pub use result::Reason;
 pub use result::TestResult;
