@@ -4,12 +4,13 @@ use crate::Report;
 
 #[derive(Debug)]
 pub enum TestResult {
-    Pass,
+    Pass(Reason),
     Fail(Reason),
 }
 
 #[derive(Debug)]
 pub enum Reason {
+    Unknown,
     Generic(String),
     NotExpected { actual: String, expected: String },
     Report(Report),
@@ -33,28 +34,13 @@ impl Reason {
     }
 }
 
-impl Display for Reason {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match &self {
-            Reason::Generic(description) => write!(f, "{}", description),
-            Reason::NotExpected { actual, expected } => {
-                write!(f, "Expected\n\n{}\n\nActual\n\n{}", expected, actual)
-            }
-            Reason::Report(report) => {
-                // TODO Pretty print instead of debug
-                write!(f, "{:#?}", &report)
-            }
-        }
-    }
-}
-
 impl From<Report> for TestResult {
     fn from(x: Report) -> Self {
         let failures = x.failures.unwrap_or(0);
+        let reason = Reason::from_report(x);
         if failures == 0 {
-            TestResult::Pass
+            TestResult::Pass(reason)
         } else {
-            let reason = Reason::from_report(x);
             TestResult::Fail(reason)
         }
     }
